@@ -16,6 +16,7 @@ from parsimonious.nodes import Node
 
 from jubeatools.formats.load_tools import make_folder_loader, round_beats
 from jubeatools.song import BeatsTime, BPMEvent, Difficulty, LongNote, NotePosition
+from jubeatools.utils import mixed_number_format
 
 from .symbols import (
     CIRCLE_FREE_SYMBOLS,
@@ -122,7 +123,7 @@ class DoubleColumnChartLine:
             raise SyntaxError(
                 f"Invalid timing part. Since #bpp={bytes_per_panel}, the timing "
                 f"part of a line should be divisible by {bytes_per_panel}, but "
-                f"{self.timing!r} is {length} bytes long so it's not"
+                f"{self.timing!r} is {length} bytes long, which isn't"
             )
 
 
@@ -198,8 +199,9 @@ class UnfinishedLongNote:
     def ends_at(self, end: BeatsTime) -> LongNote:
         if end < self.time:
             raise ValueError(
-                "Invalid end time. A long note starting at "
-                f"{self.time} cannot end at {end} (which is earlier)"
+                "Tried creating a long note with an invalid end time. A long "
+                f"note starting at beat {mixed_number_format(self.time)} cannot "
+                f"end at beat {mixed_number_format(end)} (which is earlier)"
             )
         return LongNote(
             time=self.time,
@@ -352,9 +354,19 @@ class JubeatAnalyserParser:
 
     def do_pw(self, value: str) -> None:
         if int(value) != 4:
-            raise ValueError("jubeatools only supports 4×4 charts")
+            raise ValueError(
+                f"Found a #pw command with value {value}. This means that the "
+                f"chart was written for a controller that is {value} buttons "
+                "wide. jubeatools only supports charts for 4×4 controllers"
+            )
 
-    do_ph = do_pw
+    def do_ph(self, value: str) -> None:
+        if int(value) != 4:
+            raise ValueError(
+                f"Found a #ph command with value {value}. This means that the "
+                f"chart was written for a controller that is {value} buttons "
+                "high. jubeatools only supports charts for 4×4 controllers"
+            )
 
     def do_lev(self, value: str) -> None:
         self.level = Decimal(value)
@@ -401,8 +413,9 @@ class JubeatAnalyserParser:
 
     def _wrong_format(self, f: str) -> None:
         raise ValueError(
-            f"{f} command means that this file uses another jubeat analyser "
-            "format than the one the currently selected parser is designed for"
+            f"Found a {f} command, this means that this file uses another "
+            "jubeat analyser format than the one the currently selected parser "
+            "is designed for"
         )
 
     def do_memo(self) -> None:
