@@ -97,7 +97,9 @@ class MemoParser(JubeatAnalyserParser):
 
     def do_bpp(self, value: str) -> None:
         if self.sections or self.current_frames:
-            raise ValueError("jubeatools does not handle changes of #bpp halfway")
+            raise ValueError(
+                "jubeatools does not handle changes of #bpp halfway through " "a chart"
+            )
         else:
             self._do_bpp(value)
 
