@@ -1,5 +1,5 @@
 from pathlib import Path
-from typing import Any, Optional
+from typing import Any
 
 from jubeatools import song
 from jubeatools.formats.load_tools import make_folder_loader
@@ -31,8 +31,8 @@ def load_jbsq_file(
     raw_data = construct.jbsq.parse(bytes_)
     events = [make_event_from_construct(e) for e in raw_data.events]
     chart = make_chart_from_events(events, beat_snap=beat_snap)
-    dif = guess_difficulty(file_path.stem) or song.Difficulty.EXTREME
-    return song.Song(metadata=song.Metadata(), charts={dif: chart})
+    dif = guess_difficulty(file_path.stem)
+    return song.Song(metadata=song.Metadata(), charts={dif.value: chart})
 
 
 def make_event_from_construct(e: construct.Event) -> konami.Event:
@@ -43,8 +43,8 @@ def make_event_from_construct(e: construct.Event) -> konami.Event:
     )
 
 
-def guess_difficulty(filename: str) -> Optional[song.Difficulty]:
+def guess_difficulty(filename: str) -> song.Difficulty:
     try:
         return song.Difficulty(filename[-3:].upper())
     except ValueError:
-        return None
+        return song.Difficulty.EXTREME
